use strict;
use warnings;

use Acme::CPANAuthors;
use Test::More 'tests' => 2;
use Test::NoWarnings;

# Test.
my $obj = Acme::CPANAuthors->new('Czech');
my $ret = $obj->count;
is($ret, 48, 'Count of Czech CPAN authors.');
